@@ -5,7 +5,10 @@ from .selectize import *
 from .tippy import *
 
 
-def register(modules: List[Type[Module]]):
+def register(modules: List[Type[Module]], reset: bool = False):
+    if reset:
+        Module.registered_modules = {}
+
     jscodes = []
     for m in modules:
         jscode = m.register(suppress_display=True)
