@@ -34,7 +34,7 @@ class LabExtDataTable {
             .attr({ "class": this.table_style })
             .css({ "width": "100%" })
             .appendTo(this.$container.empty());
-        $tbl.DataTable(Object.assign({ columns: this.columns, ajax: (data, callback, settings) => {
+        this.dataTable = $tbl.DataTable(Object.assign({ columns: this.columns, ajax: (data, callback, settings) => {
                 // documentation in here: https://datatables.net/manual/server-side
                 let version = this.tunnel.send_msg(JSON.stringify({
                     type: "query",
@@ -63,4 +63,10 @@ class LabExtDataTable {
                 }
             } }, this.options));
     }
+    draw() {
+        // redraw the table: https://datatables.net/reference/api/draw()
+        if (this.dataTable === undefined)
+            return;
+        this.dataTable.draw();
+    }
 }
